@@ -10,7 +10,7 @@
 
 #include "flagdivisionasker.h"
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <qimage.h>
 #include <qlayout.h>
@@ -29,7 +29,7 @@ class flagWidget : public QWidget
 		QImage img;
 
 	protected:
-		void paintEvent(QPaintEvent *)
+		void paintEvent(QPaintEvent *) override
 		{
 			QPainter p(this);
 			p.drawImage((width() - img.width()) / 2, 0, img);
